package com.travel.erp.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.travel.erp.exception.ERPException;
import com.travel.erp.exception.ErrorCodes;
import com.travel.erp.service.AlertsService;
import com.travel.erp.view.model.AlertModel;
import com.travel.erp.view.model.Failure;
import com.travel.erp.view.model.Success;

@RestController
public class AlertsController extends BaseController{
	private static final Logger logger = LoggerFactory
			.getLogger(AlertsController.class);

	@Autowired
	private AlertsService alertsService;

	@RequestMapping(path = "/lead/{leadId}/alert", method = RequestMethod.POST)
	public @ResponseBody Object addLeadAlert(
			@RequestBody AlertModel alertModel, @PathVariable int leadId) {
		try {
			alertModel.setErp_leadId(leadId);
			Integer noteId = alertsService.createLeadAlert(alertModel);

			if (noteId != null) {
				return new Success(noteId, "Alert added succesfully");
			} else {
				throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
						"Unknown error occurred");
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}

	}

	@RequestMapping(value = "/lead/{leadId}/alerts", method = RequestMethod.GET)
	public @ResponseBody Object getAlertsOfALead(@PathVariable int leadId,
			@RequestParam(required = false) String alertStatus) {
		try {
			return alertsService.getAlertsOfLead(leadId, alertStatus);
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	
	@RequestMapping(value = "/lead/{leadId}/alert/{alertId}", method = RequestMethod.PUT)
	public @ResponseBody Object updateLeadAlert(@PathVariable int leadId,
			@PathVariable int alertId, @RequestBody AlertModel alertModel) {
		try {
			alertModel.setErp_leadId(leadId);
			alertModel.setErp_alertId(alertId);
			alertsService.updateAlert(alertModel);
			return new Success(alertId, "Alert updated successfully");
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/lead/{leadId}/alert/{alertId}", method = RequestMethod.DELETE)
	public @ResponseBody Object deleteAlert(@PathVariable int leadId,
			@PathVariable int alertId) {
		try {
			alertsService.deleteAlert(alertId);
			return new Success(alertId, "Alert deleted successfully");
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/lead/{leadId}/alert/{alertId}", method = RequestMethod.GET)
	public @ResponseBody Object getAlertInfo(@PathVariable int leadId,
			@PathVariable int alertId) {
		try {
			return alertsService.getAlertDetails(alertId);
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}
}
