/**
 * 
 */
package com.travel.erp.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.travel.erp.service.BookingService;
import com.travel.erp.view.model.BookingModel;
import com.travel.erp.view.model.Failure;
import com.travel.erp.view.model.Success;

/**
 * @author Himanshu
 *
 */
@RestController
public class BookingController extends BaseController {

	private static final Logger logger = LoggerFactory.getLogger(BookingController.class);

	@Autowired
	private BookingService bookingService;

	@RequestMapping(path = "/booking/lookup/{bookingId}", method = RequestMethod.GET)
	public @ResponseBody Object bookingLookupByBookingId(@PathVariable int bookingId) {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking booking lookup for booking id: " + bookingId);
		}
		return bookingService.lookupBookingByBookingId(bookingId);
	}

	@RequestMapping(path = "/booking/saveBooking", method = RequestMethod.POST, produces = "application/json; charset=utf-8")
	public @ResponseBody Object convertToBooking(@RequestBody BookingModel bookingModel) {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking convert to booking for booking id: "
					+ bookingModel.getErp_bookingId());
		}
		int Id = bookingService.saveBooking(bookingModel);
		if (Id != 0) {
			String message = "Booking generated with booking Id: [" + Id + "]";
			return new Success(Id, message);
		}
		return new Failure();
	}

	@RequestMapping(path = "/booking/updateBooking", method = RequestMethod.POST, produces = "application/json; charset=utf-8")
	public @ResponseBody Object updateBooking(@RequestBody BookingModel bookingModel) {
		if (logger.isDebugEnabled()) {
			logger.debug(
					"BookingController :: Invoking save booking for booking id: " + bookingModel.getErp_bookingId());
		}
		Object result = null;
		try {
			bookingService.updateBooking(bookingModel);
			result = new Success(bookingModel.getErp_bookingId(), "Booking updated successfully");
		} catch (Exception ex) {
			result = new Failure("", "Booking cannot be updated");
		}
		return result;
	}

	@RequestMapping(path = "/booking/deleteBooking/{bookingId}", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object deleteBooking(@PathVariable int bookingId) {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking delete booking for booking id: " + bookingId);
		}
		Object result = null;
		try {
			bookingService.deleteBooking(bookingId);
			result = new Success(bookingId, "Booking deleted successfully");
		} catch (Exception ex) {
			result = new Failure("", "Booking cannot be deleted");
		}
		return result;
	}

	@RequestMapping(path = "/booking/getAllBookings", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object getAllBookings() {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking get all bookings.");
		}
		Object result = null;
		try {
			result = bookingService.getAllBookings();
		} catch (Exception ex) {
			ex.printStackTrace();
			result = new Failure("", "Error retreiving list of bookings");
		}
		return result;
	}

	@RequestMapping(path = "/booking/getBookingBySalesPersonId/{salesPersonId}", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object getBookingBySalesPersonId(@PathVariable int salesPersonId) {
		if (logger.isDebugEnabled()) {
			logger.debug(
					"BookingController :: Invoking get booking by salesPersonId for salesPersonId: " + salesPersonId);
		}
		Object result = null;
		try {
			result = bookingService.getBookingBySalesPersonId(salesPersonId);
		} catch (Exception ex) {
			ex.printStackTrace();
			result = new Failure("", "Error getting list of Bookings for salesPersonId: " + salesPersonId);
		}
		return result;
	}

	@RequestMapping(path = "/booking/getBookingByStatus/{status}", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object getBookingByStatus(@PathVariable String status) {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking get booking by status for status: " + status);
		}
		Object result = null;
		try {
			result = bookingService.getBookingByStatus(status);
		} catch (Exception ex) {
			ex.printStackTrace();
			result = new Failure("", "Error getting bookings by status for status: " + status);
		}
		return result;
	}

	@RequestMapping(path = "/booking/getBookingByPackageCode/{packageCode}", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object getBookingByPackageCode(@PathVariable String packageCode) {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking get booking by packageCode for packageCode: " + packageCode);
		}
		Object result = null;
		try {
			result = bookingService.getBookingByPackageCode(packageCode);
		} catch (Exception ex) {
			result = new Failure("", "Error getting bookings by packageCode for packageCode: " + packageCode);
		}
		return result;
	}

	@RequestMapping(path = "/booking/getBookingByBookingName/{bookingName}", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object getBookingByBookingName(@PathVariable String bookingName) {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking get booking by bookingName for bookingName: " + bookingName);
		}
		Object result = null;
		try {
			result = bookingService.getBookingByBookingName(bookingName);
		} catch (Exception ex) {
			result = new Failure("", "Error getting bookings by bookingName for bookingName: " + bookingName);
		}
		return result;
	}

	@RequestMapping(path = "/booking/getBookingByCreatedById/{createdById}", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object getBookingByCreatedById(@PathVariable int createdById) {
		if (logger.isDebugEnabled()) {
			logger.debug("BookingController :: Invoking get booking by createdById for createdById: " + createdById);
		}
		Object result = null;
		try {
			result = bookingService.getBookingByCreatedById(createdById);
		} catch (Exception ex) {
			result = new Failure("", "Error getting bookings by createdById for createdById: " + createdById);
		}
		return result;
	}
}