package com.travel.erp.controller;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.travel.erp.exception.ERPException;
import com.travel.erp.exception.ErrorCodes;
import com.travel.erp.service.CustomerService;
import com.travel.erp.view.model.CustomerModel;
import com.travel.erp.view.model.Failure;
import com.travel.erp.view.model.Success;

@RestController
public class CustomerController extends BaseController {

	private static final Logger logger = LoggerFactory
			.getLogger(CustomerController.class);

	@Autowired
	private CustomerService customerService;

	@RequestMapping(value = "/customer", method = RequestMethod.POST, produces = "application/json; charset=utf-8")
	public @ResponseBody Object addCustomer(@RequestBody CustomerModel customer) {
		try {
			int id = customerService.createCustomer(customer);
			if (id > 0) {
				Success success = new Success(id, "Customer added successfully");
				return success;
			} else {
				throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
						"Unknown error occurred");
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/customer/{id}", method = RequestMethod.PUT, produces = "application/json; charset=utf-8")
	public @ResponseBody Object editCustomer(@PathVariable int id,
			@RequestBody CustomerModel customer) {
		try {
			customer.setErp_id(id);
			customerService.editCustomer(customer);
			if (id > 0) {
				Success success = new Success(id,
						"Customer information updated successfully");
				return success;
			} else {
				throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
						"Unknown error occurred");
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/customer/{id}", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object getCustomer(@PathVariable int id) {
		try {
			CustomerModel customer = customerService.getCustomer(id);
			if (customer != null) {
				return customer;
			} else {
				throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
						"Unknown error occurred");
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/customer", method = RequestMethod.GET, produces = "application/json; charset=utf-8")
	public @ResponseBody Object searchCustomer(@RequestParam String emailId,
			@RequestParam String phoneNo) {
		try {
			List<CustomerModel> customers = new ArrayList<>();
			if (StringUtils.hasText(emailId)) {
				customers = customerService.searchCustomerByEmailId(emailId);
			} else if (StringUtils.hasText(phoneNo)) {
				customers = customerService.searchCustomerByPhoneNo(phoneNo);
			}
			if (customers != null) {
				return customers;
			} else {
				throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
						"Unknown error occurred");
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/customers", method = RequestMethod.GET)
	public @ResponseBody Object getAllCustomers() {
		try {
			return customerService.getAllCustomers();
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}
}
