package com.travel.erp.controller;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.travel.erp.exception.ERPException;
import com.travel.erp.exception.ErrorCodes;
import com.travel.erp.model.Employee;
import com.travel.erp.service.EmployeeService;
import com.travel.erp.view.model.EmployeeModel;
import com.travel.erp.view.model.Failure;
import com.travel.erp.view.model.LoginModel;

@RestController
public class EmployeeController extends BaseController {

	@Autowired
	private EmployeeService employeeService;

	private static final Logger logger = LoggerFactory
			.getLogger(EmployeeController.class);

	@RequestMapping(value = "/employee", method = RequestMethod.POST)
	public String addEmployee(@RequestBody Employee employee) {
		employeeService.addEmployee(employee);
		return "done";
	}

	@RequestMapping(value = "/employee", method = RequestMethod.GET)
	public @ResponseBody Object getAllEmployee() {
		try {
			List<EmployeeModel> employees = employeeService.getEmployees();
			return employees;
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/employee/login", method = RequestMethod.POST)
	public @ResponseBody Object login(@RequestBody LoginModel loginModel) {
		try {
			EmployeeModel login = employeeService.login(
					loginModel.getUserName(), loginModel.getPassword());
			if (login != null) {
				return login;
			} else {
				Failure failure = new Failure(ErrorCodes.INVALID_CREDENTIALS,
						"Username and password are incorrect");
				return failure;

			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

}
