package com.travel.erp.controller;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.travel.erp.exception.ERPException;
import com.travel.erp.exception.ErrorCodes;
import com.travel.erp.service.LeadAttachmentService;
import com.travel.erp.view.model.Failure;
import com.travel.erp.view.model.LeadAttachmentModel;
import com.travel.erp.view.model.Success;

@RestController
public class LeadAttachmentController extends BaseController {

	private static final Logger logger = LoggerFactory
			.getLogger(LeadAttachmentController.class);

	@Autowired
	private LeadAttachmentService leadAttachmentService;

	@RequestMapping(path = "/lead/{leadId}/leadAttachment", method = RequestMethod.POST, produces = "application/json; charset=utf-8")
	public @ResponseBody Object addLeadAttachment(
			@RequestBody LeadAttachmentModel attachment,
			@PathVariable int leadId) {
		try {
			attachment.setErp_leadId(leadId);
			LeadAttachmentModel addLeadAttachment = leadAttachmentService
					.addLeadAttachment(attachment);
			if (addLeadAttachment != null) {
				return addLeadAttachment;
			} else {
				throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
						"Unknown error occurred");
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}

	}

	@RequestMapping(path = "/lead/{leadId}/leadAttachments", method = RequestMethod.POST)
	public @ResponseBody Object addLeadAttachments(
			@RequestBody List<LeadAttachmentModel> attachments,
			@PathVariable int leadId) {
		try {
			for (LeadAttachmentModel attachment : attachments) {
				attachment.setErp_leadId(leadId);
			}
			List<LeadAttachmentModel> addLeadAttachments = leadAttachmentService
					.addLeadAttachments(attachments);
			if (addLeadAttachments != null) {
				return addLeadAttachments;
			} else {
				throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
						"Unknown error occurred");
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/lead/{leadId}/leadAttachment/{attId}", method = RequestMethod.GET)
	public @ResponseBody Object getLeadAttachmentByAttachmentId(
			@PathVariable int leadId, @PathVariable int attId) {
		try {
			LeadAttachmentModel leadAttachmentByAttachmentId = leadAttachmentService
					.getLeadAttachmentByAttachmentId(attId);
			if (leadAttachmentByAttachmentId != null) {
				return leadAttachmentByAttachmentId;
			} else {
				throw new ERPException(
						ErrorCodes.COULD_NOT_FIND_LEAD_ATTACHMENT,
						"Couldn't find leadAttachment with Id : " + attId);
			}
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/lead/{leadId}/leadAttachments", method = RequestMethod.GET)
	public @ResponseBody Object getAttachmentsOfALead(@PathVariable int leadId) {
		try {
			List<LeadAttachmentModel> leadAttachments = new ArrayList<>();
			leadAttachments = leadAttachmentService
					.getAttachmentsOfALead(leadId);
			return leadAttachments;
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/lead/{leadId}/leadAttachment/{attId}", method = RequestMethod.PUT)
	public @ResponseBody Object updateLeadAttachment(
			@RequestBody LeadAttachmentModel attachment,
			@PathVariable int leadId, @PathVariable int attId) {
		try {
			attachment.setErp_attId(attId);
			attachment.setErp_leadId(leadId);
			leadAttachmentService.updateLeadAttachment(attachment);
			Success success = new Success(attId,
					"Lead attachment updated successfully");
			return success;
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

	@RequestMapping(value = "/lead/{leadId}/leadAttachment/{attId}", method = RequestMethod.DELETE)
	public @ResponseBody Object deleteLeadAttachment(@PathVariable int leadId,
			@PathVariable int attId) {
		try {
			leadAttachmentService.deleteLeadAttachment(attId);
			Success success = new Success(attId,
					"Lead attachment deleted successfully");
			return success;
		} catch (ERPException e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(e.getCode(), e.getMessage());
			return failure;
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			Failure failure = new Failure(ErrorCodes.UNKNOWN_ERROR,
					e.getMessage());
			return failure;
		}
	}

}
