package com.travel.erp.dao.impl;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.MatchMode;
import org.hibernate.criterion.Restrictions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.travel.erp.dao.EmployeeDao;
import com.travel.erp.exception.ERPException;
import com.travel.erp.exception.ErrorCodes;
import com.travel.erp.model.Customer;
import com.travel.erp.model.Employee;

@Repository("employeeDao")
public class EmployeeDaoImpl implements EmployeeDao {

	@Autowired
	private SessionFactory sessionFactory;

	public EmployeeDaoImpl() {
	}

	public EmployeeDaoImpl(SessionFactory sessionFactory) {
		this.sessionFactory = sessionFactory;
	}

	@Transactional
	public void addEmployee(Employee employee) {
		sessionFactory.getCurrentSession().saveOrUpdate(employee);
	}

	@SuppressWarnings("unchecked")
	public List<Employee> getEmployees() {
		Session session = sessionFactory.openSession();
		try {
			List<Employee> list = (List<Employee>) session.createCriteria(
					Employee.class).list();
			return list;
		} catch (Exception e) {
			throw new ERPException(ErrorCodes.UNKNOWN_ERROR,
					"Could not retrieve employee list");
		} finally {
			session.close();
		}

	}

	public Employee login(String userName, String password) {
		Session session = sessionFactory.openSession();
		try {
			Criteria query = session.createCriteria(Employee.class);
			query.add(Restrictions.eq("userId", userName));
			query.add(Restrictions.eq("password", password));
			List<Employee> list = (List<Employee>) query.list();
			if (list != null && list.size() > 0) {
				return list.get(0);
			}
			return null;
		} catch (Exception e) {
			throw new ERPException(ErrorCodes.LOGIN_ERROR, e.getMessage());
		} finally {
			session.close();
		}
	}

}
