package com.travel.erp.model;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;

import com.travel.erp.view.model.BookingModel;
import com.travel.erp.view.model.HotelBookingModel;
import com.travel.erp.view.model.TravelBookingModel;

@Entity
@Table(name = "booking")
public class Booking {

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@Column(name = "bookingId", unique = true, nullable = false)
	private int bookingId;

	@OneToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "leadId")
	private Lead lead;

	private String bookingName;

	private String packageCode;

	@OneToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "salesPersonId", nullable = true)
	private Employee salesPerson;

	private int roomCount;

	private String pickupLocation;

	private String dropLocation;

	private String vehicle;

	private Double vehicleCost;

	private Double proposedPackageCost;

	private boolean taxIncluded;

	private String bookingStatus;

	private String inclusions;

	private String exclusions;

	@OneToMany
	@JoinColumn(name = "hotelBookingId", nullable = true)
	private List<HotelBooking> hotelBookings;

	@OneToMany(fetch = FetchType.EAGER)
	@JoinColumn(name = "travelBookingId", nullable = true)
	private List<TravelBooking> travelBookings;

	private int createdBy;

	private String createdAt;

	private String updatedAt;

	public Booking(BookingModel bookingModel) {
		this.setBookingId(bookingModel.getErp_bookingId());
		this.setBookingName(bookingModel.getErp_bookingName());
		this.setPackageCode(bookingModel.getErp_packageCode());
		this.setSalesPerson(new Employee(bookingModel.getErp_salesPerson()));
		this.setRoomCount(bookingModel.getErp_roomCount());
		this.setPickupLocation(bookingModel.getErp_pickupLocation());
		this.setDropLocation(bookingModel.getErp_dropLocation());
		this.setVehicle(bookingModel.getErp_vehicle());
		this.setVehicleCost(bookingModel.getErp_vehicleCost());
		this.setProposedPackageCost(bookingModel.getErp_proposedPackageCost());
		this.setTaxIncluded(bookingModel.isErp_taxIncluded());
		this.setBookingStatus(bookingModel.getErp_bookingStatus());
		this.setInclusions(bookingModel.getErp_inclusions());
		this.setExclusions(bookingModel.getErp_exclusions());
		this.setHotelBookingsModel(bookingModel.getErp_hotelBookings());
		this.setTravelBookingsModel(bookingModel.getErp_travelBookings());
		this.setCreatedAt(bookingModel.getErp_createdAt());
		this.setCreatedBy(bookingModel.getErp_createdBy());
		this.setUpdatedAt(bookingModel.getErp_updatedAt());
	}

	public int getBookingId() {
		return bookingId;
	}

	public void setBookingId(int bookingId) {
		this.bookingId = bookingId;
	}

	public Lead getLead() {
		return lead;
	}

	public void setLead(Lead lead) {
		this.lead = lead;
	}

	public String getBookingName() {
		return bookingName;
	}

	public void setBookingName(String bookingName) {
		this.bookingName = bookingName;
	}

	public String getPackageCode() {
		return packageCode;
	}

	public void setPackageCode(String packageCode) {
		this.packageCode = packageCode;
	}

	public Employee getSalesPerson() {
		return salesPerson;
	}

	public void setSalesPerson(Employee salesPerson) {
		this.salesPerson = salesPerson;
	}

	public int getRoomCount() {
		return roomCount;
	}

	public void setRoomCount(int roomCount) {
		this.roomCount = roomCount;
	}

	public String getPickupLocation() {
		return pickupLocation;
	}

	public void setPickupLocation(String pickupLocation) {
		this.pickupLocation = pickupLocation;
	}

	public String getDropLocation() {
		return dropLocation;
	}

	public void setDropLocation(String dropLocation) {
		this.dropLocation = dropLocation;
	}

	public String getVehicle() {
		return vehicle;
	}

	public void setVehicle(String vehicle) {
		this.vehicle = vehicle;
	}

	public Double getVehicleCost() {
		return vehicleCost;
	}

	public void setVehicleCost(Double vehicleCost) {
		this.vehicleCost = vehicleCost;
	}

	public Double getProposedPackageCost() {
		return proposedPackageCost;
	}

	public void setProposedPackageCost(Double proposedPackageCost) {
		this.proposedPackageCost = proposedPackageCost;
	}

	public boolean isTaxIncluded() {
		return taxIncluded;
	}

	public void setTaxIncluded(boolean taxIncluded) {
		this.taxIncluded = taxIncluded;
	}

	public String getBookingStatus() {
		return bookingStatus;
	}

	public void setBookingStatus(String bookingStatus) {
		this.bookingStatus = bookingStatus;
	}

	public String getInclusions() {
		return inclusions;
	}

	public void setInclusions(String inclusions) {
		this.inclusions = inclusions;
	}

	public String getExclusions() {
		return exclusions;
	}

	public void setExclusions(String exclusions) {
		this.exclusions = exclusions;
	}

	public void setTravelBookingsModel(List<TravelBookingModel> travelBookings) {
		if (travelBookings != null) {
			List<TravelBooking> travelBooking = new ArrayList<>();
			for (TravelBookingModel thisTravelBooking : travelBookings) {
				travelBooking.add(new TravelBooking(thisTravelBooking));
			}
			this.travelBookings = travelBooking;
		}
	}

	public void setTravelBookings(List<TravelBooking> travelBookings) {
		this.travelBookings = travelBookings;
	}

	public List<TravelBooking> getTravelBookings() {
		return travelBookings;
	}

	public List<HotelBooking> getHotelBookings() {
		return hotelBookings;
	}

	public void setHotelBookingsModel(List<HotelBookingModel> hotelBookings) {
		if (hotelBookings != null) {
			List<HotelBooking> hotelBooking = new ArrayList<>();
			for (HotelBookingModel thisHotelBooking : hotelBookings) {
				hotelBooking.add(new HotelBooking(thisHotelBooking));
			}
			this.hotelBookings = hotelBooking;
		}
	}

	public void setHotelBookings(List<HotelBooking> hotelBookings) {
		this.hotelBookings = hotelBookings;
	}

	public int getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(int createdBy) {
		this.createdBy = createdBy;
	}

	public String getCreatedAt() {
		return createdAt;
	}

	public void setCreatedAt(String createdAt) {
		this.createdAt = createdAt;
	}

	public String getUpdatedAt() {
		return updatedAt;
	}

	public void setUpdatedAt(String updatedAt) {
		this.updatedAt = updatedAt;
	}

	public Booking() {
	}
}