package com.travel.erp.model;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.travel.erp.util.Utils;
import com.travel.erp.view.model.CustomerModel;

@Entity
@Table(name = "customer")
public class Customer {

	private Integer id;
	private String name;
	private String emailId;
	private String phoneNo;
	private String city;
	private String country;
	private Date dateOfBirth;
	private Date creationTime;
	private Date updateTime;
	private Employee createdBy;

	public Customer() {
	}

	public Customer(CustomerModel customer) {
		this.id = customer.getErp_id();
		this.name = customer.getErp_name();
		this.city = customer.getErp_city();
		this.country = customer.getErp_country();
		Employee emp = new Employee();
		emp.setId(customer.getErp_createdBy());
		this.createdBy = emp;
		if (customer.getErp_dateOfBirth() != null) {
			this.dateOfBirth = Utils.getDateFromString(customer
					.getErp_dateOfBirth());
		}
		this.emailId = customer.getErp_emailId();
		this.phoneNo = customer.getErp_phoneNo();
	}

	@Id
	@GeneratedValue
	@Column(name = "id", unique = true, nullable = false)
	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}

	@Column(name = "name", nullable = false, length = 100)
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	@Column(name = "emailId", unique = true, nullable = false, length = 100)
	public String getEmailId() {
		return emailId;
	}

	public void setEmailId(String emailId) {
		this.emailId = emailId;
	}

	@Column(name = "phoneNo", unique = true, nullable = false, length = 15)
	public String getPhoneNo() {
		return phoneNo;
	}

	public void setPhoneNo(String phoneNo) {
		this.phoneNo = phoneNo;
	}

	@Column(name = "city", length = 45)
	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	@Column(name = "country", length = 45)
	public String getCountry() {
		return country;
	}

	public void setCountry(String country) {
		this.country = country;
	}

	@Column(name = "dateOfBirth")
	public Date getDateOfBirth() {
		return dateOfBirth;
	}

	public void setDateOfBirth(Date dateOfBirth) {
		this.dateOfBirth = dateOfBirth;
	}

	@Column(name = "creationTime")
	public Date getCreationTime() {
		return creationTime;
	}

	public void setCreationTime(Date creationTime) {
		this.creationTime = creationTime;
	}

	@Column(name = "updateTime")
	public Date getUpdateTime() {
		return updateTime;
	}

	public void setUpdateTime(Date updateTime) {
		this.updateTime = updateTime;
	}

	@ManyToOne
	@JoinColumn(name = "createdBy")
	public Employee getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(Employee createdBy) {
		this.createdBy = createdBy;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + id;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Customer other = (Customer) obj;
		if (id != other.id)
			return false;
		return true;
	}

}
