package com.travel.erp.model;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import org.springframework.util.StringUtils;

import com.travel.erp.util.Utils;
import com.travel.erp.view.model.LeadModel;

@Entity
@Table(name = "lead")
public class Lead {
	@Id
	@GeneratedValue
	@Column(name = "id")
	private Integer id;

	@ManyToOne
	@JoinColumn(name = "customerId")
	private Customer customer;

	@Column(name = "destinations", nullable = false, length = 200)
	private String destinations;

	@Column(name = "adultCount")
	private Integer adultCount;

	@Column(name = "kidsCount")
	private Integer kidsCount;

	@Column(name = "departureDate")
	private Date departureDate;

	@Column(name = "nights")
	private Integer nights;

	@Column(name = "leavingFrom")
	private String leavingFrom;

	@Column(name = "leadSource")
	private String leadSource;

	@Column(name = "additionalInfo")
	private String additionalInfo;

	@Column(name = "leadStatus")
	private String leadStatus;

	@Column(name = "creationTime")
	private Date creationTime;

	@Column(name = "updateTime")
	private Date updateTime;

	@ManyToOne
	@JoinColumn(name = "createdBy")
	private Employee createdBy;

	@ManyToOne
	@JoinColumn(name = "assignedTo")
	private Employee assignedTo;

	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}

	public Customer getCustomer() {
		return customer;
	}

	public void setCustomer(Customer customer) {
		this.customer = customer;
	}

	public String getDestinations() {
		return destinations;
	}

	public void setDestinations(String destinations) {
		this.destinations = destinations;
	}

	public Integer getAdultCount() {
		return adultCount;
	}

	public void setAdultCount(Integer adultCount) {
		this.adultCount = adultCount;
	}

	public Integer getKidsCount() {
		return kidsCount;
	}

	public void setKidsCount(Integer kidsCount) {
		this.kidsCount = kidsCount;
	}

	public Date getDepartureDate() {
		return departureDate;
	}

	public void setDepartureDate(Date departureDate) {
		this.departureDate = departureDate;
	}

	public Integer getNights() {
		return nights;
	}

	public void setNights(Integer nights) {
		this.nights = nights;
	}

	public String getLeavingFrom() {
		return leavingFrom;
	}

	public void setLeavingFrom(String leavingFrom) {
		this.leavingFrom = leavingFrom;
	}

	public String getLeadSource() {
		return leadSource;
	}

	public void setLeadSource(String leadSource) {
		this.leadSource = leadSource;
	}

	public String getAdditionalInfo() {
		return additionalInfo;
	}

	public void setAdditionalInfo(String additionalInfo) {
		this.additionalInfo = additionalInfo;
	}

	public String getLeadStatus() {
		return leadStatus;
	}

	public void setLeadStatus(String leadStatus) {
		this.leadStatus = leadStatus;
	}

	public Date getCreationTime() {
		return creationTime;
	}

	public void setCreationTime(Date creationTime) {
		this.creationTime = creationTime;
	}

	public Date getUpdateTime() {
		return updateTime;
	}

	public void setUpdateTime(Date updateTime) {
		this.updateTime = updateTime;
	}

	public Employee getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(Employee createdBy) {
		this.createdBy = createdBy;
	}

	public Employee getAssignedTo() {
		return assignedTo;
	}

	public void setAssignedTo(Employee assignedTo) {
		this.assignedTo = assignedTo;
	}

	public Lead() {
	}

	public Lead(LeadModel leadModel) {
		this.id = leadModel.getErp_id();
		if (leadModel.getErp_customerId() != null) {
			Customer customer = new Customer();
			customer.setId(leadModel.getErp_customerId());
			this.customer = customer;
		}
		this.destinations = StringUtils
				.isEmpty(leadModel.getErp_destinations()) ? leadModel
				.getErp_destinations() : leadModel.getErp_destinations()
				.toUpperCase();
		this.adultCount = leadModel.getErp_adultCount();
		this.kidsCount = leadModel.getErp_kidsCount();
		if (leadModel.getErp_departureDate() != null) {
			this.departureDate = Utils.getDateFromString(leadModel
					.getErp_departureDate());
		}

		this.nights = leadModel.getErp_nights();
		this.leavingFrom = leadModel.getErp_leavingFrom();
		this.leadSource = leadModel.getErp_leadSource();
		this.additionalInfo = leadModel.getErp_additionalInfo();
		this.leadStatus = leadModel.getErp_leadStatus();
		if (leadModel.getErp_createdBy() != null) {
			Employee createdBy = new Employee();
			createdBy.setId(leadModel.getErp_createdBy());
			this.createdBy = createdBy;
		}
		if (leadModel.getErp_assignedTo() != null) {
			Employee assignedTo = new Employee();
			assignedTo.setId(leadModel.getErp_assignedTo());
			this.assignedTo = assignedTo;
		}
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + id;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Lead other = (Lead) obj;
		if (id != other.id)
			return false;
		return true;
	}

}
