package com.travel.erp.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.travel.erp.dao.AlertsDao;
import com.travel.erp.model.Alert;
import com.travel.erp.service.AlertsService;
import com.travel.erp.view.model.AlertModel;

@Service("alertsService")
public class AlertsServiceImpl implements AlertsService {

	@Autowired
	private AlertsDao alertsDao;

	@Override
	public int createLeadAlert(AlertModel alertModel) {
		Alert alert = new Alert(alertModel);
		return alertsDao.createLeadAlert(alert);
	}

	@Override
	public void updateAlert(AlertModel alertModel) {
		Alert alert = new Alert(alertModel);
		alertsDao.updateAlert(alert);
	}

	@Override
	public void deleteAlert(int alertId) {
		alertsDao.deleteAlert(alertId);
	}

	@Override
	public AlertModel getAlertDetails(int alertId) {
		Alert alertDetails = alertsDao.getAlertDetails(alertId);
		if (alertDetails != null) {
			return new AlertModel(alertDetails);
		}
		return null;
	}

	@Override
	public List<AlertModel> getAlertsOfLead(int leadId, String alertStatus) {
		List<AlertModel> alerts = new ArrayList<>();
		List<Alert> alertsOfLead = alertsDao.getAlertsOfLead(leadId,
				alertStatus);
		if (alertsOfLead != null) {
			for (Alert alert : alertsOfLead) {
				alerts.add(new AlertModel(alert));
			}
			return alerts;
		}
		return null;
	}

	@Override
	public List<AlertModel> getAlertsByAssignedTo(int employeeId,
			String alertStatus) {
		List<AlertModel> alerts = new ArrayList<>();
		List<Alert> alertList = alertsDao.getAlertsByAssignedTo(employeeId,
				alertStatus);
		if (alertList != null) {
			for (Alert alert : alertList) {
				alerts.add(new AlertModel(alert));
			}
			return alerts;
		}
		return null;
	}

	@Override
	public List<AlertModel> getAlertsByAlertDate(Date date) {
		List<AlertModel> alerts = new ArrayList<>();
		List<Alert> alertList = alertsDao.getAlertsByAlertDate(date);
		if (alertList != null) {
			for (Alert alert : alertList) {
				alerts.add(new AlertModel(alert));
			}
			return alerts;
		}
		return null;
	}

}
