package com.travel.erp.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.travel.erp.dao.LeadDao;
import com.travel.erp.model.Lead;
import com.travel.erp.model.LeadSource;
import com.travel.erp.model.LeadStatus;
import com.travel.erp.service.AlertsService;
import com.travel.erp.service.LeadAttachmentService;
import com.travel.erp.service.LeadService;
import com.travel.erp.service.NotesService;
import com.travel.erp.view.model.LeadModel;

@Service("leadService")
public class LeadServiceImpl implements LeadService {

	@Autowired
	private LeadDao leadDao;

	@Autowired
	private LeadAttachmentService leadAttachmentService;

	@Autowired
	private NotesService notesService;

	@Autowired
	private AlertsService alertsService;

	public int createLead(LeadModel leadModel) {
		Lead lead = new Lead(leadModel);
		return leadDao.createLead(lead);
	}

	public LeadModel getLeadInfo(int id) {
		Lead leadInfo = leadDao.getLeadInfo(id);
		if (leadInfo != null) {
			LeadModel leadModel = new LeadModel(leadInfo);
			leadModel.setErp_leadAttachments(leadAttachmentService
					.getAttachmentsOfALead(id));
			leadModel.setErp_notes(notesService.getNotesOfALead(id));
			leadModel.setErp_alerts(alertsService.getAlertsOfLead(id, "ALL"));
			return leadModel;
		}
		return null;
	}

	@Override
	public void updateLead(LeadModel leadModel) {
		Lead lead = new Lead(leadModel);
		leadDao.updateLead(lead);
	}

	@Override
	public void deleteLead(int leadId) {
		leadDao.deleteLead(leadId);
	}

	@Override
	public List<LeadModel> searchLeads(Integer leadId, String emailId,
			String phoneNo, String destinations, Integer customerId,
			String departureDate, String leadSource, String leadStatus,
			Integer createdBy, Integer assignedTo, String fromDate,
			String toDate) {
		List<Lead> searchLeads = leadDao.searchLeads(leadId, emailId, phoneNo,
				destinations, customerId, departureDate, leadSource,
				leadStatus, createdBy, assignedTo, fromDate, toDate);
		List<LeadModel> leadModels = new ArrayList<>();
		if (searchLeads != null) {
			for (Lead searchLead : searchLeads) {
				leadModels.add(new LeadModel(searchLead));
			}
		}
		return leadModels;
	}

	@Override
	public List<LeadStatus> getLeadStatusValues() {
		return leadDao.getLeadStatusValues();
	}

	@Override
	public List<LeadSource> getLeadSources() {
		return leadDao.getLeadSources();
	}

}
