package com.travel.erp.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.travel.erp.dao.BookingDao;
import com.travel.erp.dao.NotesDao;
import com.travel.erp.exception.ERPException;
import com.travel.erp.exception.ErrorCodes;
import com.travel.erp.model.Booking;
import com.travel.erp.model.Note;
import com.travel.erp.service.NotesService;
import com.travel.erp.view.model.NoteModel;

@Service("notesService")
public class NotesServiceImpl implements NotesService{

	@Autowired
	private NotesDao notesDao;

	@Autowired
	private BookingDao bookingDao;

	@Override
	public int addNotesToLead(NoteModel noteModel) {
		Note note = new Note(noteModel);
		return notesDao.addNotes(note);
	}

	@Override
	public int addNotesToBooking(NoteModel noteModel) {
		Booking booking = bookingDao.getBooking(noteModel.getErp_bookingId());
		if (booking != null) {
			Integer leadId = booking.getLead().getId();
			noteModel.setErp_leadId(leadId);
			Note note = new Note(noteModel);
			return notesDao.addNotes(note);
		} else {
			throw new ERPException(ErrorCodes.COULD_NOT_FIND_BOOKING,
					"Could not find booking with Id : "
							+ noteModel.getErp_bookingId());
		}
	}

	@Override
	public List<NoteModel> getNotesOfALead(int leadId) {
		List<NoteModel> noteModels = new ArrayList<>();
		List<Note> notesOfALead = notesDao.getNotesOfALead(leadId);
		if (notesOfALead != null) {
			for (Note note : notesOfALead) {
				noteModels.add(new NoteModel(note));
			}
		}
		return noteModels;
	}

	@Override
	public List<NoteModel> getNotesOfABooking(int bookingId) {
		Booking booking = bookingDao.getBooking(bookingId);
		if (booking != null) {
			return getNotesOfALead(booking.getLead().getId());
		} else {
			throw new ERPException(ErrorCodes.COULD_NOT_FIND_BOOKING,
					"Could not find booking with Id : " + bookingId);
		}

	}

	@Override
	public NoteModel getNoteInfo(int noteId) {
		Note noteInfo = notesDao.getNoteInfo(noteId);
		if (noteInfo != null) {
			return new NoteModel(noteInfo);
		}
		return null;
	}

	@Override
	public void updateNoteOfALead(Integer leadId, NoteModel noteModel) {
		noteModel.setErp_leadId(leadId);
		Note note = new Note(noteModel);
		notesDao.updateNote(note);
	}

	@Override
	public void updateNoteOfABooking(Integer bookingId, NoteModel noteModel) {
		Booking booking = bookingDao.getBooking(bookingId);
		if (booking != null) {
			updateNoteOfALead(booking.getLead().getId(), noteModel);
		} else {
			throw new ERPException(ErrorCodes.COULD_NOT_FIND_BOOKING,
					"Could not find booking with Id : " + bookingId);
		}
	}

	@Override
	public void deleteNote(int noteId) {
		notesDao.deleteNote(noteId);
	}
}
